<?php
/*
Plugin Name: Shadowbox JS
Plugin URI: http://sivel.net/wordpress/shadowbox-js/
Description: A javascript media viewer similar to Lightbox and Thickbox. Supports all types of media, not just images. 
Version: 2.0.4.1
Author: Matt Martz
Author URI: http://sivel.net

	Copyright (c) 2009 Matt Martz (http://sivel.net)
	Shadowbox JS is released under the GNU General Public License (LGPL)
	http://www.gnu.org/licenses/lgpl-2.1.txt

	Shadowbox (c) 2008 Michael J. I. Jackson (http://mjijackson.com/shadowbox)
	Shadowbox is licensed under the Creative Commons Attribution-Noncommercial-Share Alike license
	http://creativecommons.org/licenses/by-nc-sa/3.0/
*/

/**
 * If we are in the admin load the admin functionality
 */
if ( is_admin () )
	require_once( dirname ( __FILE__ ) . '/inc/admin.php' );

/**
 * Get specific option from the options table
 *
 * @param string $option Name of option to be used as array key for retrieving the specific value
 * @return mixed 
 * @since 2.0.3
 */
function shadowbox_option ( $option ) {
	$shadowbox = get_option ( 'shadowbox' );
	if ( isset ( $shadowbox[$option] ) )
		return $shadowbox[$option];
	else
		return false;
}

/**
 * Get the full URL to the plugin
 *
 * @return string
 * @since 2.0.3
 */
function shadowbox_plugin_url () {
	$shadowbox_plugin_url = plugins_url ( plugin_basename ( dirname ( __FILE__ ) ) );
	return $shadowbox_plugin_url;
}

/**
 * Enqueue Shadowbox CSS 
 *
 * @since 2.0.3
 */
function shadowbox_styles () {
	$shadowbox_plugin_url = shadowbox_plugin_url ();
	$skin = apply_filters ( 'shadowbox_skin' , $shadowbox_plugin_url . '/skin/' . shadowbox_option ( 'skin' ) );
	$skin = preg_replace ( '|/$|' , '' , $skin );
	if ( ! stristr ( $skin , '/skin/none/' ) )
		wp_enqueue_style ( 'shadowbox-skin' , $skin . '/skin.css' , false , false , 'screen' );
	wp_enqueue_style ( 'shadowbox-extras' , $shadowbox_plugin_url . '/css/extras.css' , false , '2.0.4.0' , 'screen' );
}

/**
 * Enqueue Shadowbox javascript and dependencies
 * 
 * @since 2.0.3
 */
function shadowbox_scripts () {
	$shadowbox_plugin_url = shadowbox_plugin_url ();
	$adapter = 'shadowbox-' . shadowbox_option ( 'library' );
	$language = shadowbox_option ( 'language' );
	$skin = apply_filters ( 'shadowbox_skin' , $shadowbox_plugin_url . '/skin/' . shadowbox_option ( 'skin' ) );
	$skin = preg_replace ( '|/$|' , '' , $skin );
	wp_register_script ( 'yui' , 'http://yui.yahooapis.com/2.6.0/build/yahoo-dom-event/yahoo-dom-event.js' , false , '2.6.0' , true );
	wp_register_script ( 'ext-base' , $shadowbox_plugin_url . '/js/ext-base.js' , false , '2.0.2' , true );
	wp_register_script ( 'ext-core' , $shadowbox_plugin_url . '/js/ext-core.js' , false , '2.0.2' , true );
	wp_register_script ( 'dojo' , 'http://ajax.googleapis.com/ajax/libs/dojo/1.2.3/dojo/dojo.xd.js' , false , '1.2.3' , true );
	wp_register_script ( 'mootools' , 'http://ajax.googleapis.com/ajax/libs/mootools/1.2.1/mootools-yui-compressed.js' , false , '1.2.1' , true );
	wp_register_script ( 'shadowbox-base' , $shadowbox_plugin_url . '/js/adapter/shadowbox-base.js' , false , '2.0' , true );
	wp_register_script ( 'shadowbox-yui' , $shadowbox_plugin_url . '/js/adapter/shadowbox-yui.js' , array ( 'yui' ) , '2.0' , true );
	wp_register_script ( 'shadowbox-prototype' , $shadowbox_plugin_url . '/js/adapter/shadowbox-prototype.js' , array ( 'prototype' ) , '2.0' , true );
	wp_register_script ( 'shadowbox-jquery' , $shadowbox_plugin_url . '/js/adapter/shadowbox-jquery.js' , array ( 'jquery' ) , '2.0' , true );
	wp_register_script ( 'shadowbox-ext' , $shadowbox_plugin_url . '/js/adapter/shadowbox-ext.js' , array ( 'ext-base' , 'ext-core' ) , '2.0' , true );
	wp_register_script ( 'shadowbox-dojo' , $shadowbox_plugin_url . '/js/adapter/shadowbox-dojo.js' , array ( 'dojo' ) , '2.0' , true );
	wp_register_script ( 'shadowbox-mootools' , $shadowbox_plugin_url . '/js/adapter/shadowbox-mootools.js' , array ( 'mootools' ) , '2.0' , true );
	wp_register_script ( 'shadowbox' , $shadowbox_plugin_url . '/js/shadowbox-2.0.js' , array ( $adapter ) , '2.0' , true );
	wp_register_script ( 'shadowbox-lang' , $shadowbox_plugin_url . '/js/lang/shadowbox-' . $language . '.js' , array ( 'shadowbox' ) , '2.0' , true );
	if ( ! stristr ( $skin , '/skin/none/' ) )
		wp_register_script ( 'shadowbox-skin' , $skin . '/skin.js' , array ( 'shadowbox' ) , false , true );
	wp_enqueue_script ( 'shadowbox-lang' );
	wp_enqueue_script ( 'shadowbox-skin' );
	if ( ! did_action ( 'wp_print_styles' ) )
		wp_print_styles ();
}

/**
 * Echo Shadowbox configuration and initialization scripts

 * @since 0.1
 */
function shadowbox_configure () {
	$library = shadowbox_option ( 'library' );
	$shadowbox_start = "\n<!-- Begin Shadowbox JS -->\n";
	$shadowbox_end = "<!-- End Shadowbox JS -->\n\n";

	// Shadowbox initialization options
	$shadowbox_init_ops  = '		animate: ' . shadowbox_option ( 'animate' ) . ',' . "\n";
	$shadowbox_init_ops .= '		animateFade: ' . shadowbox_option ( 'animateFade' ) . ',' . "\n";
	$shadowbox_init_ops .= '		animSequence: "' . shadowbox_option ( 'animSequence' ) . '",' . "\n";
	$shadowbox_init_ops .= '		modal: ' . shadowbox_option ( 'modal' ) . ',' . "\n";
	$shadowbox_init_ops .= '		overlayColor: "' . shadowbox_option ( 'overlayColor' ) . '",' . "\n";
	$shadowbox_init_ops .= '		overlayOpacity: ' . shadowbox_option ( 'overlayOpacity' ) . ',' . "\n";
	$shadowbox_init_ops .= '		flashBgColor: "' . shadowbox_option ( 'flashBgColor' ) . '",' . "\n";
	$shadowbox_init_ops .= '		autoplayMovies: ' . shadowbox_option ( 'autoplayMovies' ) . ',' . "\n";
	$shadowbox_init_ops .= '		showMovieControls: ' . shadowbox_option ( 'showMovieControls' ) . ',' . "\n";
	$shadowbox_init_ops .= '		slideshowDelay: ' . shadowbox_option ( 'slideshowDelay' ) . ',' . "\n";
	$shadowbox_init_ops .= '		resizeDuration: ' . shadowbox_option ( 'resizeDuration' ) . ',' . "\n";
	$shadowbox_init_ops .= '		fadeDuration: ' . shadowbox_option ( 'fadeDuration' ) . ',' . "\n";
	$shadowbox_init_ops .= '		displayNav: ' . shadowbox_option ( 'displayNav' ) . ',' . "\n";
	$shadowbox_init_ops .= '		continuous: ' . shadowbox_option ( 'continuous' ) . ',' . "\n";
	$shadowbox_init_ops .= '		displayCounter: ' . shadowbox_option ( 'displayCounter' ) . ',' . "\n";
	$shadowbox_init_ops .= '		counterType: "' . shadowbox_option ( 'counterType' ) . '",' . "\n";
	$shadowbox_init_ops .= '		counterLimit: ' . shadowbox_option ( 'counterLimit' ) . ',' . "\n";
	$shadowbox_init_ops .= '		viewportPadding: ' . shadowbox_option ( 'viewportPadding' ) . ',' . "\n";
	$shadowbox_init_ops .= '		handleOversize: "' . shadowbox_option ( 'handleOversize' ) . '",' . "\n";
	$shadowbox_init_ops .= '		handleUnsupported: "' . shadowbox_option ( 'handleUnsupported' ) . '",' . "\n";
	$shadowbox_init_ops .= '		initialHeight: ' . shadowbox_option ( 'initialHeight' ) . ',' . "\n";
	$shadowbox_init_ops .= '		initialWidth: ' . shadowbox_option ( 'initialWidth' ) . ',' . "\n";
	$shadowbox_init_ops .= '		enableKeys: ' . shadowbox_option ( 'enableKeys' ) . ',' . "\n";
	$shadowbox_init_ops .= '		flvPlayer: "' . shadowbox_plugin_url () . '/flvplayer.swf"';

	// The full Shadowbox configuration
	$shadowbox_init  = "<script type=\"text/javascript\">\n";
	$shadowbox_init .= "	var shadowbox_conf = {\n";
	$shadowbox_init .= "$shadowbox_init_ops\n";
	$shadowbox_init .= "	};\n";
	
	switch ( $library ) :
		case 'yui' :
			$shadowbox_init .= "	YAHOO.util.Event.onDOMReady(function() {\n";
			break;
		case 'prototype' :
			$shadowbox_init .= "	document.observe(\"dom:loaded\", function() {\n";
			break;
		case 'jquery' :
			$shadowbox_init .= "	jQuery(document).ready(function () {\n";
			break;
		case 'ext' :
			$shadowbox_init .= "	Ext.EventManager.onDocumentReady(function() {\n";
			break;
		case 'dojo' :
			$shadowbox_init .= "	dojo.addOnLoad(function() {\n";
			break;
		case 'mootools' :
			$shadowbox_init .= "	window.addEvent(\"domready\", function() {\n";
			break;
		default :
			$shadowbox_init .= "	window.onload = (function(){\n";
			break;
	endswitch;

	$shadowbox_init .= "		Shadowbox.init(shadowbox_conf);\n";
	$shadowbox_init .= "	});\n";
	$shadowbox_init .= "</script>\n";

	echo $shadowbox_start . $shadowbox_init . $shadowbox_end;
}

/**
 * Returns whether or not a specific type or all of the automations are enabled
 *
 * @return boolean
 * @since 2.0.4.0
 */
function shadowbox_is_automatic ( $type = null ) {
	switch ($type) :
		case 'img':
		case 'mov':
		case 'aud':
		case 'tube':
			if ( shadowbox_option ( "auto{$type}" ) == "true" )
				return true;
			else
				return false;
			break;
		default:
			if ( shadowbox_option ( 'autoimg' ) == "true" || 
			     shadowbox_option ( 'automov' ) == "true" || 
			     shadowbox_option ( 'autoaud' ) == "true" || 
			     shadowbox_option ( 'autotube' ) == "true" )
				return true;
			else
				return false;
			break;
	endswitch;
}

/**
 * This function is called by the add_filter WordPress function to 
 * link the gallery images directly to their full size counterpart
 *
 * @param string $link The link of the attachment
 * @param integer $id The id of the post
 * @return string
 * @since 2.0.1
 */
if ( ! function_exists ( 'attachment_direct_linkage' ) ) :
	function attachment_direct_linkage ( $link , $id ) {
		$mimetypes = array ( 'image/jpeg' , 'image/png' , 'image/gif' );
		$post = get_post ( $id );
		if ( in_array ( $post->post_mime_type , $mimetypes ) )
			return wp_get_attachment_url ( $id );
		else
			return $link;
	}
endif;

/**
 * This function is called by the add_filter WordPress function to add 
 * the rel="shadowbox[post-123]" attribute to all links of a specified
 * type.
 *
 * @param string $content The content of the post
 * @return string
 * @since 2.0.3
 */
function shadowbox_add_attr_to_link ( $content ) {
	global $post;
	
	// Search Patterns
	$img_pattern = '/<a(.*?)href=(\'|")([^>]*)\.(bmp|gif|jpe?g|png)(\'|")(.*?)>/i';
	$mov_pattern = '/<a(.*?)href=(\'|")([^>]*)\.(swf|flv|f4v|dv|moo?v|movie|mp4|asf|wmv?|avi|mpe?g)(\'|")(.*?)>/i';
	$aud_pattern = '/<a(.*?)href=(\'|")([^>]*)\.(mp3|aac)(\'|")(.*?)>/i';
	$tube_pattern = '/<a(.*?)href=(\'|")([^>]*)(youtube\.com\/(watch|v\/)|video\.google\.com\/googleplayer.swf)(.*?)(\'|")(.*?)>/i';
	$master_pattern = '/<a(.*?)href=(\'|")([^>]*)(\.(bmp|gif|jpe?g|png|swf|flv|f4v|dv|moo?v|movie|mp4|asf|wmv?|avi|mpe?g|mp3|aac)(\'|")|(youtube\.com\/(watch|v\/)|video\.google\.com\/googleplayer.swf))(.*?)>/i';	

	// Rel attrs for different file types
	$img_rel_attr = 'rel=$2shadowbox[post-' . $post->ID . '];player=img;$5';
	$mov_rel_attr = 'rel=$2shadowbox[post-' . $post->ID . ']$5';
	$aud_rel_attr = 'rel=$2shadowbox[post-' . $post->ID . '];player=flv;height=0;$5';
	$tube_rel_attr = 'rel=$2shadowbox[post-' . $post->ID . '];width=640;height=385;$7';

	// Replacement patterns
	$img_replace = '<a$1href=$2$3.$4$5 ' . $img_rel_attr . '$6>';
	$mov_replace = '<a$1href=$2$3.$4$5 ' . $mov_rel_attr . '$6>';
	$aud_replace = '<a$1href=$2$3.$4$5 ' . $aud_rel_attr . '$6>';
	$tube_replace = '<a$1href=$2$3$4$6$7 ' . $tube_rel_attr . '$8>';

	// Non specific search patterns
	$rel_pattern = '/\ rel=(\'|")(.*?)(\'|")/i';
	$box_rel_pattern = '/\ rel=(\'|")(.*?)(shadow|light|no)box(.*?)(\'|")/i';

	if ( preg_match_all ( $master_pattern , $content , $links ) ) :
		foreach ( $links[0] as $link ) :
			
			if ( preg_match ( $img_pattern , $link ) && shadowbox_option ( 'autoimg' ) == "true" ) :
				$link_pattern = $img_pattern;
				$rel_attr = $img_rel_attr;
				$link_replace = $img_replace;
			elseif ( preg_match ( $mov_pattern , $link ) && shadowbox_option ( 'automov' ) == "true" ) :
				$link_pattern = $mov_pattern;
				$rel_attr = $mov_rel_attr;
				$link_replace = $mov_replace;
			elseif ( preg_match ( $aud_pattern , $link ) && shadowbox_option ( 'autoaud' ) == "true" ) :
				$link_pattern = $aud_pattern;
				$rel_attr = $aud_rel_attr;
				$link_replace = $aud_replace;
			elseif ( preg_match ( $tube_pattern , $link ) && shadowbox_option ( 'autotube' ) == "true" ) :
				$link_pattern = $tube_pattern;
				$rel_attr = $tube_rel_attr;
				$link_replace = $tube_replace;
			else :
				return $content;
			endif;

			if ( ! preg_match ( $rel_pattern , $link ) ) :
				$link_replace = preg_replace ( $link_pattern , $link_replace , $link );
				$content = str_replace ( $link , $link_replace , $content );
			else :
				if ( ! preg_match ( $box_rel_pattern , $link ) ) :
					preg_match ( $rel_pattern , $link , $link_rel );
					$link_no_rel = preg_replace( $rel_pattern , '' , $link );
					$link_replace = preg_replace ( $link_pattern , $link_replace , $link_no_rel );
					$content = str_replace ( $link , $link_replace , $content );
				endif;
			endif;
		endforeach;
	endif;
	return $content;
}

/**
 * Add IE7 Compatibility meta tag to head of document so Shadowbox can work with IE8
 *
 * @param string $buffer Contents stored in output buffer
 * @return string
 * @since 2.0.4.1
 */
function shadowbox_ie8_hack($buffer) {
	return preg_replace('|((.*)<title>([^<]+)</title>)|i', "$1\n\n$2<meta http-equiv='X-UA-Compatible' content='IE=7' />\n", $buffer);
}

/**
 * Start output buffer
 *
 * @since 2.0.4.1
 */
function shadowbox_start_buffer() {
	ob_start('shadowbox_ie8_hack');
}

/**
 * Stop and flush the output buffer
 *
 * @since 2.0.4.1
 */
function shadowbox_flush_buffer() {
	ob_end_flush();
}

// WordPress hooks
// only hook in if the options are in the options table so that WordPress will still function
if ( get_option ( 'shadowbox' ) ) :
	// Enqueue the Shadowbox CSS and JS files and print Shadowbox init to the head
	if ( ! function_exists ( 'wp_enqueue_scripts' ) ) :
		add_action ( 'wp_head' , 'shadowbox_styles' , 8 );
		add_action ( 'wp_head' , 'shadowbox_scripts' , 9 );
	else :
		add_action ( 'wp_enqueue_scripts' , 'shadowbox_styles' );
		add_action ( 'wp_enqueue_scripts' , 'shadowbox_scripts' );
	endif;
	add_action ( 'wp_footer' , 'shadowbox_configure' , 11 );
	if ( shadowbox_option ( 'ie8hack' ) == 'true' ) {
		add_action ( 'get_header' , 'shadowbox_start_buffer' , 100 );
		add_action ( 'wp_head' , 'shadowbox_flush_buffer', 0 );
	}

	// Automatically add Shadowbox to links
	if ( shadowbox_is_automatic ('all') ) {
		add_filter ( 'the_content' , 'shadowbox_add_attr_to_link' , 11 );
		add_filter ( 'the_excerpt' , 'shadowbox_add_attr_to_link' , 11 );
	}
	if ( shadowbox_is_automatic ('img') )
		add_filter ( 'attachment_link' , 'attachment_direct_linkage' , 10 , 2 );
endif;
?>
